Change in libosmo-sccp[master]: Don't use deprecated osmo_stream_cli_open2()

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Max gerrit-no-reply at lists.osmocom.org
Thu Feb 7 10:07:34 UTC 2019


Max has uploaded this change for review. ( https://gerrit.osmocom.org/12852


Change subject: Don't use deprecated osmo_stream_cli_open2()
......................................................................

Don't use deprecated osmo_stream_cli_open2()

Using osmo_stream_cli_open() with explicit timeout set via
osmo_stream_cli_set_reconnect_timeout() will have the same
effect. Update comment explaining this as well as the code.

Change-Id: Iffe6ea48a170880faef071c7c4a1bc0605aa9855
---
M src/osmo_ss7.c
1 file changed, 4 insertions(+), 3 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/libosmo-sccp refs/changes/52/12852/1

diff --git a/src/osmo_ss7.c b/src/osmo_ss7.c
index 39d92fa..05668b0 100644
--- a/src/osmo_ss7.c
+++ b/src/osmo_ss7.c
@@ -1261,12 +1261,13 @@
 		else
 			osmo_stream_cli_set_read_cb(asp->client, xua_cli_read_cb);
 		osmo_stream_cli_set_data(asp->client, asp);
-		rc = osmo_stream_cli_open2(asp->client, 1);
+		rc = osmo_stream_cli_open(asp->client);
 		if (rc < 0) {
 			LOGSS7(asp->inst, LOGL_ERROR, "Unable to open stream"
 				" client for ASP %s\n", asp->cfg.name);
-			/* we don't return error in here because osmo_stream_cli_open2()
-			   will continue to retry to connect so the error is transient  */
+			/* we don't return error in here because osmo_stream_cli_open()
+			   will continue to retry (due to timeout being explicitly set with
+			   osmo_stream_cli_set_reconnect_timeout() above) to connect so the error is transient */
 		}
 		/* TODO: make this configurable and not implicit */
 		role = XUA_ASPFSM_ROLE_ASP;

-- 
To view, visit https://gerrit.osmocom.org/12852
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: libosmo-sccp
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: Iffe6ea48a170880faef071c7c4a1bc0605aa9855
Gerrit-Change-Number: 12852
Gerrit-PatchSet: 1
Gerrit-Owner: Max <msuraev at sysmocom.de>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20190207/3aaf86c7/attachment.htm>


More information about the gerrit-log mailing list